Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(734)

Unified Diff: src/mirror-delay.js

Issue 21080: Added the 'references' command to the debugger protocol to provide access to ... (Closed) Base URL: http://v8.googlecode.com/svn/branches/bleeding_edge/
Patch Set: '' Created 11 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/debug-delay.js ('k') | test/mjsunit/debug-references.js » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/mirror-delay.js
===================================================================
--- src/mirror-delay.js (revision 1230)
+++ src/mirror-delay.js (working copy)
@@ -690,15 +690,16 @@
/**
* Returns objects which has direct references to this object
* @param {number} opt_max_instances Optional parameter specifying the maximum
* number of instances to return.
* @return {Array} The objects which has direct references to this object.
*/
-ObjectMirror.prototype.referencedBy = function(opt_max_instances) {
- // Find all objects constructed from this function.
- var result = %DebugReferencedBy(this.value_, Mirror.prototype, opt_max_instances || 0);
+ObjectMirror.prototype.referencedBy = function(opt_max_objects) {
+ // Find all objects with direct references to this object.
+ var result = %DebugReferencedBy(this.value_,
+ Mirror.prototype, opt_max_objects || 0);
- // Make mirrors for all the instances found.
+ // Make mirrors for all the references found.
for (var i = 0; i < result.length; i++) {
result[i] = MakeMirror(result[i]);
}
@@ -690,15 +690,16 @@
/**
* Returns objects which has direct references to this object
- * @param {number} opt_max_instances Optional parameter specifying the maximum
- * number of instances to return.
+ * @param {number} opt_max_objects Optional parameter specifying the maximum
+ * number of referencing objects to return.
* @return {Array} The objects which has direct references to this object.
*/
« no previous file with comments | « src/debug-delay.js ('k') | test/mjsunit/debug-references.js » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698